'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var core = require('use-intl/core');
var getConfig = require('./getConfig.js');
var resolveLocaleArg = require('./resolveLocaleArg.js');

const getFormatterImpl = React.cache(async locale => {
  const config = await getConfig.default(locale);
  return core.createFormatter(config);
});

/**
 * Returns a formatter based on the given locale.
 *
 * The formatter automatically receives the request config, but
 * you can override it by passing in additional options.
 */
async function getFormatter(opts) {
  const locale = await resolveLocaleArg.default(opts);
  return getFormatterImpl(locale);
}

exports.default = getFormatter;
